#undef PACKAGE
#undef VERSION
#undef HAVE_LIBSM
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_GMP2_INCLUDE_DIR
#undef HAVE_WORDEXP
#undef HAVE_MPFR
#undef GETTEXT_PACKAGE
#undef HAVE_GTKSOURCEVIEW
#undef USE_NCURSES
#undef INC_NCURSES
#undef HAVE_SETENV
#undef HAVE_UNSETENV
#undef HAVE_CLEARENV
